@@ -17,6 +17,24 @@ test_that("nesting doesn't expand values", {
   expect_equal(expand(df, nesting(x, y)), df)
 })
 
+test_that("unnamed data frames are flattened", {
+  df <- data.frame(x = 1:2, y = 1:2)
+  out <- expand(df, nesting(x, y))
+  expect_equal(out$x, df$x)
+
+  out <- crossing(df)
+  expect_equal(out$x, df$x)
+})
+
+test_that("named data frames are not flattened", {
+  df <- data.frame(x = 1:2, y = 1:2)
+  out <- expand(df, x = nesting(x, y))
+  expect_equal(out$x, df)
+
+  out <- crossing(x = df)
+  expect_equal(out$x, df)
+})
+
 test_that("expand works with non-standard col names", {
   df <- tibble(` x ` = 1:2, `/y` = 1:2)
   out <- expand(df, ` x `, `/y`)
@@ -52,31 +70,38 @@ test_that("preserves NAs", {
   expect_equal(nesting(x)$x, x)
 })
 
-test_that("zero length numeric & character inputs are automatically dropped", {
-  tb <- tibble(x = 1:5)
-  expect_equal(expand(tb, x, y = numeric()), tb)
-  expect_equal(nesting(x = tb$x, y = numeric()), tb)
-  expect_equal(crossing(x = tb$x, y = numeric()), tb)
+test_that("crossing preserves factor levels", {
+  x_na_lev_extra <- factor(c("a", NA), levels = c("a", "b", NA), exclude = NULL)
+  expect_equal(levels(crossing(x = x_na_lev_extra)$x), c("a", "b", NA))
+})
 
-  expect_equal(expand(tb, x, y = character()), tb)
-  expect_equal(nesting(x = tb$x, y = character()), tb)
-  expect_equal(crossing(x = tb$x, y = character()), tb)
+test_that("NULL inputs", {
+  tb <- tibble(x = 1:5)
+  expect_equal(expand(tb, x, y = NULL), tb)
+  expect_equal(nesting(x = tb$x, y = NULL), tb)
+  expect_equal(crossing(x = tb$x, y = NULL), tb)
 })
 
 test_that("zero length input gives zero length output", {
   tb <- tibble(x = character())
-  expect_equal(expand(tb, x), tibble())
+  expect_equal(expand(tb, x), tb)
   expect_equal(expand(tb, y = NULL), tibble())
+
+  expect_equal(
+    expand_grid(x = integer(), y = 1:3),
+    tibble(x = integer(), y = integer())
+  )
 })
 
-test_that("zero length factor inputs are completed by expand & crossing, dropped by nesting", {
-  tb <- tibble(x = 1:2)
-  emptyfactor <- factor(levels = c("a", "b"))
-  targettb <- tibble(x = as.integer(c(1, 1, 2, 2)), y = factor(c("a", "b", "a", "b"), levels = c("a", "b")))
+test_that("expand & crossing expand missing factor leves; nesting does not", {
+  tb <- tibble(
+    x = 1:3,
+    f = factor("a", levels = c("a", "b"))
+  )
 
-  expect_equal(expand(tb, x, y = emptyfactor), targettb)
-  expect_equal(nesting(x = tb$x, y = emptyfactor), tb)
-  expect_equal(crossing(x = tb$x, y = emptyfactor), targettb)
+  expect_equal(nrow(expand(tb, x, f)), 6)
+  expect_equal(nrow(crossing(!!!tb)), 6)
+  expect_equal(nrow(nesting(!!!tb)), nrow(tb))
 })
 
 test_that("expand() reconstructs input dots is empty", {
@@ -87,6 +112,17 @@ test_that("expand() reconstructs input dots is empty", {
 test_that("crossing checks for bad inputs", {
   expect_error(
     crossing(x = 1:10, y = quote(a)),
-    "Problems: y"
+    class = "vctrs_error_scalar_type"
   )
 })
+
+test_that("crossing handles list columns", {
+  x <- 1:2
+  y <- list(1, 1:2)
+  out <- crossing(x, y)
+
+  expect_equal(nrow(out), 4)
+  expect_s3_class(out, "tbl_df")
+  expect_equal(out$x, rep(x, each = 2))
+  expect_equal(out$y, rep(y, 2))
+})
